@@ -74,6 +74,8 @@ Menu::Menu(XfceRc* settings) :
 	// Create the window
 	m_window = GTK_WINDOW(gtk_window_new(GTK_WINDOW_TOPLEVEL));
 	gtk_widget_set_name(GTK_WIDGET(m_window), "whiskermenu-window");
+	// Untranslated window title to allow window managers to identify it; not visible to users.
+	gtk_window_set_title(m_window, "Whisker Menu");
 	gtk_window_set_modal(m_window, true);
 	gtk_window_set_decorated(m_window, false);
 	gtk_window_set_skip_taskbar_hint(m_window, true);
@@ -1004,9 +1006,18 @@ void Menu::check_command(Command& command, GtkWidget* button)
 {
 	if (command.m_status == Unchecked)
 	{
-		gchar* path = g_find_program_in_path(command.m_exec.c_str());
-		command.m_status = path ? Valid : Invalid;
-		g_free(path);
+		gchar** argv;
+		if (g_shell_parse_argv(command.m_exec.c_str(), NULL, &argv, NULL))
+		{
+			gchar* path = g_find_program_in_path(argv[0]);
+			command.m_status = path ? Valid : Invalid;
+			g_free(path);
+			g_strfreev(argv);
+		}
+		else
+		{
+			command.m_status = Invalid;
+		}
 	}
 	gtk_widget_set_sensitive(button, command.m_status == Valid);
 }
